import typer
from typing import Annotated
from rich.console import Console
from nixprstatus.pr import pr_merge_status

app = typer.Typer()

DEFAULT_HEADERS = {
    "Accept": "application/vnd.github.text+json",
}

BRANCHES = ["nixos-unstable-small", "nixos-unstable", "nixos-24.05"]


@app.command()
def pr(
    pr: int,
    branches: Annotated[
        list[str] | None, typer.Option(help="Check specific branch")
    ] = None,
):
    """Get status of pull request"""
    console = Console()

    if branches:
        status = pr_merge_status(pr, branches)
    else:
        status = pr_merge_status(pr)
    merged = ":white_check_mark: merged" if status.merged else ":x: merged"
    console.print(merged, highlight=False)

    for branch in status.branches:
        output = (
            f":white_check_mark: {branch}"
            if status.branches[branch]
            else f":x: {branch}"
        )
        console.print(output, highlight=False)


def main():
    app()


if __name__ == "__main__":
    main()
